constant

package
v0.57.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ValueOf

func ValueOf[T Constant[T]]() T

ValueOf gives the default value of a constant from its type. It's helpful when constructing constants as variants in a one-of. Note that empty structs are marshalled by default. Usage: constant.ValueOf[constant.Foo]()

Types

type AppVersionSummary

type AppVersionSummary string // Always "app_version_summary"

func (AppVersionSummary) Default

func (AppVersionSummary) MarshalJSON

func (c AppVersionSummary) MarshalJSON() ([]byte, error)

type AwsUsEast1a

type AwsUsEast1a string // Always "aws.us-east-1a"

func (AwsUsEast1a) Default

func (c AwsUsEast1a) Default() AwsUsEast1a

func (AwsUsEast1a) MarshalJSON

func (c AwsUsEast1a) MarshalJSON() ([]byte, error)

type ConsoleError added in v0.57.0

type ConsoleError string // Always "console_error"

func (ConsoleError) Default added in v0.57.0

func (c ConsoleError) Default() ConsoleError

func (ConsoleError) MarshalJSON added in v0.57.0

func (c ConsoleError) MarshalJSON() ([]byte, error)

type ConsoleLog added in v0.57.0

type ConsoleLog string // Always "console_log"

func (ConsoleLog) Default added in v0.57.0

func (c ConsoleLog) Default() ConsoleLog

func (ConsoleLog) MarshalJSON added in v0.57.0

func (c ConsoleLog) MarshalJSON() ([]byte, error)

type Constant

type Constant[T any] interface {
	Default() T
}

type DeploymentState

type DeploymentState string // Always "deployment_state"

func (DeploymentState) Default

func (c DeploymentState) Default() DeploymentState

func (DeploymentState) MarshalJSON

func (c DeploymentState) MarshalJSON() ([]byte, error)

type Error

type Error string // Always "error"

func (Error) Default

func (c Error) Default() Error

func (Error) MarshalJSON

func (c Error) MarshalJSON() ([]byte, error)

type InteractionClick added in v0.57.0

type InteractionClick string // Always "interaction_click"

func (InteractionClick) Default added in v0.57.0

func (c InteractionClick) Default() InteractionClick

func (InteractionClick) MarshalJSON added in v0.57.0

func (c InteractionClick) MarshalJSON() ([]byte, error)

type InteractionKey added in v0.57.0

type InteractionKey string // Always "interaction_key"

func (InteractionKey) Default added in v0.57.0

func (c InteractionKey) Default() InteractionKey

func (InteractionKey) MarshalJSON added in v0.57.0

func (c InteractionKey) MarshalJSON() ([]byte, error)

type InteractionScrollSettled added in v0.57.0

type InteractionScrollSettled string // Always "interaction_scroll_settled"

func (InteractionScrollSettled) Default added in v0.57.0

func (InteractionScrollSettled) MarshalJSON added in v0.57.0

func (c InteractionScrollSettled) MarshalJSON() ([]byte, error)

type InvocationState

type InvocationState string // Always "invocation_state"

func (InvocationState) Default

func (c InvocationState) Default() InvocationState

func (InvocationState) MarshalJSON

func (c InvocationState) MarshalJSON() ([]byte, error)

type Log

type Log string // Always "log"

func (Log) Default

func (c Log) Default() Log

func (Log) MarshalJSON

func (c Log) MarshalJSON() ([]byte, error)

type ManagedAuthState added in v0.31.1

type ManagedAuthState string // Always "managed_auth_state"

func (ManagedAuthState) Default added in v0.31.1

func (c ManagedAuthState) Default() ManagedAuthState

func (ManagedAuthState) MarshalJSON added in v0.31.1

func (c ManagedAuthState) MarshalJSON() ([]byte, error)

type MonitorDisconnected added in v0.57.0

type MonitorDisconnected string // Always "monitor_disconnected"

func (MonitorDisconnected) Default added in v0.57.0

func (MonitorDisconnected) MarshalJSON added in v0.57.0

func (c MonitorDisconnected) MarshalJSON() ([]byte, error)

type MonitorInitFailed added in v0.57.0

type MonitorInitFailed string // Always "monitor_init_failed"

func (MonitorInitFailed) Default added in v0.57.0

func (MonitorInitFailed) MarshalJSON added in v0.57.0

func (c MonitorInitFailed) MarshalJSON() ([]byte, error)

type MonitorReconnectFailed added in v0.57.0

type MonitorReconnectFailed string // Always "monitor_reconnect_failed"

func (MonitorReconnectFailed) Default added in v0.57.0

func (MonitorReconnectFailed) MarshalJSON added in v0.57.0

func (c MonitorReconnectFailed) MarshalJSON() ([]byte, error)

type MonitorReconnected added in v0.57.0

type MonitorReconnected string // Always "monitor_reconnected"

func (MonitorReconnected) Default added in v0.57.0

func (MonitorReconnected) MarshalJSON added in v0.57.0

func (c MonitorReconnected) MarshalJSON() ([]byte, error)

type MonitorScreenshot added in v0.57.0

type MonitorScreenshot string // Always "monitor_screenshot"

func (MonitorScreenshot) Default added in v0.57.0

func (MonitorScreenshot) MarshalJSON added in v0.57.0

func (c MonitorScreenshot) MarshalJSON() ([]byte, error)

type NetworkIdle added in v0.57.0

type NetworkIdle string // Always "network_idle"

func (NetworkIdle) Default added in v0.57.0

func (c NetworkIdle) Default() NetworkIdle

func (NetworkIdle) MarshalJSON added in v0.57.0

func (c NetworkIdle) MarshalJSON() ([]byte, error)

type NetworkLoadingFailed added in v0.57.0

type NetworkLoadingFailed string // Always "network_loading_failed"

func (NetworkLoadingFailed) Default added in v0.57.0

func (NetworkLoadingFailed) MarshalJSON added in v0.57.0

func (c NetworkLoadingFailed) MarshalJSON() ([]byte, error)

type NetworkRequest added in v0.57.0

type NetworkRequest string // Always "network_request"

func (NetworkRequest) Default added in v0.57.0

func (c NetworkRequest) Default() NetworkRequest

func (NetworkRequest) MarshalJSON added in v0.57.0

func (c NetworkRequest) MarshalJSON() ([]byte, error)

type NetworkResponse added in v0.57.0

type NetworkResponse string // Always "network_response"

func (NetworkResponse) Default added in v0.57.0

func (c NetworkResponse) Default() NetworkResponse

func (NetworkResponse) MarshalJSON added in v0.57.0

func (c NetworkResponse) MarshalJSON() ([]byte, error)

type PageDomContentLoaded added in v0.57.0

type PageDomContentLoaded string // Always "page_dom_content_loaded"

func (PageDomContentLoaded) Default added in v0.57.0

func (PageDomContentLoaded) MarshalJSON added in v0.57.0

func (c PageDomContentLoaded) MarshalJSON() ([]byte, error)

type PageLayoutSettled added in v0.57.0

type PageLayoutSettled string // Always "page_layout_settled"

func (PageLayoutSettled) Default added in v0.57.0

func (PageLayoutSettled) MarshalJSON added in v0.57.0

func (c PageLayoutSettled) MarshalJSON() ([]byte, error)

type PageLayoutShift added in v0.57.0

type PageLayoutShift string // Always "page_layout_shift"

func (PageLayoutShift) Default added in v0.57.0

func (c PageLayoutShift) Default() PageLayoutShift

func (PageLayoutShift) MarshalJSON added in v0.57.0

func (c PageLayoutShift) MarshalJSON() ([]byte, error)

type PageLcp added in v0.57.0

type PageLcp string // Always "page_lcp"

func (PageLcp) Default added in v0.57.0

func (c PageLcp) Default() PageLcp

func (PageLcp) MarshalJSON added in v0.57.0

func (c PageLcp) MarshalJSON() ([]byte, error)

type PageLoad added in v0.57.0

type PageLoad string // Always "page_load"

func (PageLoad) Default added in v0.57.0

func (c PageLoad) Default() PageLoad

func (PageLoad) MarshalJSON added in v0.57.0

func (c PageLoad) MarshalJSON() ([]byte, error)
type PageNavigation string // Always "page_navigation"
func (c PageNavigation) Default() PageNavigation
func (c PageNavigation) MarshalJSON() ([]byte, error)
type PageNavigationSettled string // Always "page_navigation_settled"
func (c PageNavigationSettled) MarshalJSON() ([]byte, error)

type PageTabOpened added in v0.57.0

type PageTabOpened string // Always "page_tab_opened"

func (PageTabOpened) Default added in v0.57.0

func (c PageTabOpened) Default() PageTabOpened

func (PageTabOpened) MarshalJSON added in v0.57.0

func (c PageTabOpened) MarshalJSON() ([]byte, error)

type SseHeartbeat

type SseHeartbeat string // Always "sse_heartbeat"

func (SseHeartbeat) Default

func (c SseHeartbeat) Default() SseHeartbeat

func (SseHeartbeat) MarshalJSON

func (c SseHeartbeat) MarshalJSON() ([]byte, error)

Jump to